apply_refund

Function apply_refund 

pub fn apply_refund<DB: Database, I>(
    evm: &mut TempoEvm<DB, I>,
    gas: &mut Gas,
) -> Result<(), EVMError<DB::Error, TempoInvalidTransaction>>
Applies storage-credit settlement at the end of a transaction.

During execution, each account’s transaction-local mode and pending Refund creations are stored in one transient word at the same key as its persistent balance. At end-of-transaction, entries with non-zero pending creations are settled against the same account’s persistent storage credit balance, consuming up to min(pending, balance) credits and refunding one fixed storage credit value per credit. Mode-only transient entries are ignored.